# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`resolv`](#resolv): Configures /etc/resolv.conf or the NetworkManager equivalent
* [`resolv::host_conf`](#resolvhost_conf): Configures /etc/host.conf

### Data types

* [`Resolv::Domain`](#resolvdomain): Valid values for the resolv.conf "domain" option
* [`Resolv::Sortlist`](#resolvsortlist): Valid resolv.conf `sortlist` field

## Classes

### `resolv`

Configures /etc/resolv.conf or the NetworkManager equivalent

* **See also**
  * resolv.conf(5)

#### Parameters

The following parameters are available in the `resolv` class.

##### `ensure`

Data type: `Enum['present', 'absent']`

Remove the resolv.conf from the system if set to `absent`

* No other actions will be performed on the resolv.conf file if this is set

Default value: `'present'`

##### `servers`

Data type: `Optional[Variant[Boolean[false], Array[Simplib::IP,0,3]]]`

An array of servers to query. If the first server is '127.0.0.1' or '::1'
then the host will be set up as a caching DNS server unless $caching is
set to false.  The other hosts will be used as the higher level
nameservers

* Set to `false` to actively remove this option from the configuration

Default value: `simplib::lookup('simp_options::dns::servers', 'default_value' => undef )`

##### `search`

Data type: `Optional[Variant[Boolean[false], Array[Simplib::Domain]]]`

Array of entries that will be searched, in order, for hosts.

* Set to `false` to actively remove this option from the configuration

Default value: `simplib::lookup('simp_options::dns::search', 'default_value' => undef )`

##### `resolv_domain`

Data type: `Optional[Variant[Boolean[false], Resolv::Domain]]`

Local domain name, defaults to the domain of your host.

* This is obsolete, please use `$search` instead.

* Set to `false` to actively remove this option from the configuration

Default value: ``undef``

##### `debug`

Data type: `Boolean`

Print debugging messages

Default value: ``false``

##### `rotate`

Data type: `Boolean`

When `true`, enables round-robin selection of $servers to distribute the
query load.

Default value: ``true``

##### `no_check_names`

Data type: `Boolean`

When `true`, disables the modern BIND checking of incoming hostnames and
mail names for invalid characters such as underscore (`_`), non-ASCII, or
control characters.

Default value: ``false``

##### `inet6`

Data type: `Boolean`

When `true`, use AAAA (IPv6) queries and convert A (IPv4) results

Default value: ``false``

##### `ndots`

Data type: `Variant[Boolean[false], Integer[0,15]]`

Value for the `ndots:` option in resolv.conf

* Set to `false` to actively remove this option from the configuration

Default value: `1`

##### `timeout`

Data type: `Variant[Boolean[false], Integer[0,30]]`

Amount of time (in seconds) the resolver will wait for a response

* Set to `false` to actively remove this option from the configuration

Default value: `2`

##### `attempts`

Data type: `Variant[Boolean[false], Integer[0,5]]`

Number of times to attempt querying $servers before giving up

* Set to `false` to actively remove this option from the configuration

Default value: `2`

##### `named_server`

Data type: `Boolean`

A boolean that states that this server is definitively a named server.
Bypasses the need for $named_autoconf below.

Default value: ``false``

##### `named_autoconf`

Data type: `Boolean`

A boolean that controlls whether or not to autoconfigure named.
true           => If the server where puppet is being run is in the list of
        $servers then automatically configure named.
false          => Do not autoconfigure named.

Default value: ``true``

##### `caching`

Data type: `Boolean`

*If* the $servers array above starts with '127.0.0.1' or '::1', then
the system will set itself up as a caching nameserver unless this is set
to false.

Default value: ``true``

##### `use_nmcli`

Data type: `Boolean`

Allows the user to update DNS entries via nmcli instead of directly
modifying resolv.conf

Default value: `pick($facts.dig('simplib__networkmanager', 'enabled'), false)`

##### `nmcli_connection_name`

Data type: `Optional[String[1]]`

**DEPRECATED** => Remains for API until next release

Default value: ``undef``

##### `nmcli_ignore_auto_dns`

Data type: `Optional[Boolean]`

**DEPRECATED** => Remains for API until next release

Default value: ``undef``

##### `nmcli_auto_reapply_device`

Data type: `Optional[Boolean]`

**DEPRECATED** => Remains for API until next release

Default value: ``undef``

##### `sortlist`

Data type: `Optional[Variant[Boolean[false], Resolv::Sortlist]]`

Optional Array of address/netmask pairs that allow addresses returned by
gethostbyname to be sorted.

* Set to `false` to actively remove this option from the configuration

Default value: ``undef``

##### `extra_options`

Data type: `Optional[Array[String[1]]]`

Optional Array to put any options that may not be covered by the variables
below. These will be appended to the options string.

* Adding `--` in front of any option will actively remove it from the
  configuration if not using NMCLI
* When using NMCLI , '--' items will be ignored since it is authoritative

@example Manage Extra Options

  ---
  extra_options:
    # Add ip6-bytestring
    - 'ip6-bytestring'
    # Ensure that ip6-dotint is not set
    - '--ip6-dotint'

Default value: ``undef``

##### `content`

Data type: `Optional[Variant[Array[String[1]], String[1]]]`

Unless in NMCLI mode, ignores all other options and writes the specified
content to `/etc/resolv.conf`

Default value: ``undef``

##### `ignore_dhcp_dns`

Data type: `Boolean`

Ignores entries passed down from DHCP

Default value: ``true``

### `resolv::host_conf`

Configures /etc/host.conf

* **See also**
  * host.conf(5)

#### Parameters

The following parameters are available in the `resolv::host_conf` class.

##### `trim`

Data type: `Optional[Array[Pattern[/^\./]]]`



Default value: ``undef``

##### `multi`

Data type: `Boolean`



Default value: ``true``

##### `reorder`

Data type: `Boolean`



Default value: ``true``

##### `spoof`

Data type: `Optional[String]`

defunct, see: https://bugzilla.redhat.com/show_bug.cgi?id=1577265)

Remains to prevent issues with direct ``class`` calls.

Default value: ``undef``

## Data types

### `Resolv::Domain`

Valid values for the resolv.conf "domain" option

Alias of `Variant[Simplib::Domain, Enum['.']]`

### `Resolv::Sortlist`

Valid resolv.conf `sortlist` field

Alias of `Array[Variant[Simplib::IP,Simplib::IP::V4::DDQ,Simplib::IP::V6], 0, 10]`

